import { csv, select } from 'd3';
import { scatterPlot } from './scatterplot.js';

const csvUrl =
  'https://gist.githubusercontent.com/RahulBelede/13d05d3379bdf5d826b41f49705b3eee/raw/9d77db0d69b1f59279c07c0f4d1b1a8981b89cd9/gistfile1.txt';

const parseRow = (d) => {
  return {
    Car_Type: d.Car_Type,
    2019: +d['2019_Sales'],
    2020: +d['2020_Sales'],
    2021: +d['2021_Sales'],
  };
};

const width = window.innerWidth * 0.8;
const height = window.innerHeight * 0.8;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d['2021']) // X-axis: 2021 sales
    .yValue((d) => d['2019']) // Y-axis: 2019 sales
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);

  const columns = ['2019', '2020', '2021']; // For animation
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};

main();
